package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````T!]```````!``````````!#'````
M`````````$``.``(`$``&@`9``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````-2W````````U+<`````````
M`"````````$````&`````,``````````P&````````#`8```````1`0`````
M``"H"0``````````(````````@````8````HP````````"C`8```````*,!@
M``````#P`0```````/`!````````"``````````$````!````!@"````````
M&`)````````8`D```````!@`````````&``````````$`````````%#E=&0$
M````B+,```````"(LT```````(BS0```````U`````````#4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````
M!`````$```!&<F5E0E-$`,R[#0!A````9@```````````````````#D`````
M````*P```&,````B``````````````!.`````````%(```!,`````````#0`
M```\````80````(````M````50```%X````V````.@``````````````'0``
M`$L````D````5``````````J````7P```$T````+`````````&````!B````
M)P```&4`````````/0````````!1````6@```%,```!=```````````````&
M````'````!(````C````+P````H````X````/P```$,```!;`````````$0`
M```^`````````%``````````````````````````5@```"@````7````2@``
M`"P```!!`````````````````````P```!L````%````9````%P```!"````
M`````!\````)````````````````````0`````````!7````#P````````!%
M````1@```````````````````````````````0``````````````````````
M````````````````````````````````````````#0``````````````````
M```````````````````````````````````````````````````````:````
M````````````````&0````@````1````````````````````%`````P````.
M`````````!4````E```````````````````````````````8````````````
M````````````````````````````````````````(````!,`````````````
M```````P````,@``````````````*0`````````>````%@```"8```!)````
M`````#,`````````(0```$\````N````````````````````````````````
M````-0```#<`````````!````$<```!(````$````%@``````````````#$`
M```[````60````<`````````````````````````````````````````A0$`
M`!(``````````````"$!````````J@,``!(`#``0/$````````4`````````
MNP,``!(`#`#@($```````#0`````````#````!(``````````````!4`````
M````(`0``!(``````````````!X`````````>@,``!(`#`#0'T```````)P`
M````````%@```!(``````````````&$%````````C`(``!(`````````````
M````````````(0```!$`%P!@Q&````````$`````````/@(``!(`````````
M`````*P`````````.````"``````````````````````````@0(``!$`%@`@
MQ&````````@`````````3````!(`#0!45$``````````````````R`,``!(`
M#`!P4$```````%(#````````W@,``!(`#`!@.$```````$T`````````[`,`
M`!(`#`!`.T```````,D`````````4@```!(``````````````#L$````````
M6P```!$`%P!PQ&````````$`````````9@```!(``````````````/``````
M````=````!(``````````````$(``````````@0``!(`#`!`04```````.(`
M````````#@0``!(`#``004```````"(`````````A````!$`%P"`Q&``````
M``$`````````D@```!(``````````````&$!````````R`(``!(`````````
M`````"\`````````]@(``!(```````````````P`````````*00``!(`#``P
M0D```````&T`````````9P,``!(```````````````\`````````#@,``!(`
M````````````````````````6`,``!(``````````````&P`````````H```
M`!$`%P"0Q&````````@`````````10,``!(`````````````````````````
MJ@```!(``````````````"L`````````'`,``!(```````````````(`````
M````M0```!(```````````````H#````````8`,``!(``````````````%4`
M````````+0,``!(``````````````)``````````PP```!$`%P"8Q&``````
M``@`````````-0,``!(``````````````)``````````2`(``!(`````````
M`````$H`````````R0```!(``````````````!4`````````P@(``!(`````
M`````````&<`````````UP```!$`%P"@Q&````````@`````````LP(``!(`
M`````````````/0`````````Y````!(```"$'4```````,X!````````0P(`
M`!(``````````````'$`````````]````!$`%P"HQ&````````$`````````
M_P```!(```````````````\!````````$`$``!(``````````````*H'````
M````/0,``!(``````````````"$`````````1`,``!(`````````````````
M````````'P$``!$`%P"PQ&````````@`````````)@,``!(`````````````
M````````````I0(``!(`````````````````````````GP(``!(`````````
M````````````````-00``!(`#`#04T```````!0`````````JP(``!(`````
M`````````#0`````````+P$``!(``````````````&@!````````/@$``!(`
M`````````````)$"````````3`$``!(``````````````!\:````````SP(`
M`!(`````````````````````````!@,``!(``````````````$P`````````
MY0(``!(```````````````P`````````=0,``!``\?]$Q&``````````````
M````6@$``!$`%P"@R6````````@`````````8@$``!(``````````````.0`
M````````>0(``!(``````````````(\0````````3@(``!(`````````````
M`#$`````````N@(``!(```````````````H`````````<@(``!(`````````
M`````$H`````````;@$``!$`%P"XQ&````````@`````````/00``!(`#`"P
M.$```````!X`````````8`(``!$`%P#`Q&```````$``````````2@,``!(`
M`````````````'P`````````@0,``!``\?^HR6``````````````````U@(`
M`!(`````````````````````````%0,``!(``````````````%0`````````
M>0$``!(``````````````#8`````````C`$``!(``````````````)``````
M````F0$``!$`%P``Q6````````$`````````I@$``!$`%P`0Q6```````!,`
M````````R@(``!(``````````````"\`````````600``!(`#`!`1D``````
M`"P*````````M0$``!(``````````````(T`````````;@,``!``\?]$Q&``
M````````````````$0```!(``````````````"P'````````P`$``!(`````
M`````````,4"````````9@0``!(`#``P/D```````!<!````````>`0``!(`
M#`"01$```````*P!````````A00``!$`%@`XQ&````````@`````````RP$`
M`!(``````````````&<`````````W0(``!(``````````````$H`````````
M_0(``!(``````````````)L`````````E0(``!$`%P!`Q6````````@`````
M````40,``!(``````````````'X`````````CP0``!(`#`!0/T```````+X!
M````````G`0``!(`#`"@0D```````/`!````````-P0``!(`"@#`&T``````
M````````````V@$``!$`%P!(Q6````````@`````````Y`$``!(`````````
M`````'P`````````^P$``!(``````````````)T(`````````&QI8G!E<FPN
M<V\`<&5R;%]F<F5E`'!E<FQ?<&%R<V4`4$Q?<&5R;%]D97-T<G5C=%]L979E
M;`!?2G9?4F5G:7-T97)#;&%S<V5S`%]F:6YI`'!E<FQ?<G5N`%!,7VEN7V5V
M86P`4&5R;%]A=E]S:&EF=`!097)L7V=V7V9E=&-H<'8`4$Q?97AI=%]F;&%G
M<P!097)L7W-V7W-E='!V`%!,7V-O;7!C=@!P97)L7V%L;&]C`%!E<FQ?9&]U
M;G=I;F0`4$Q?;W``4&5R;%]S>7-?=&5R;0!03%]E=F%L7W)O;W0`8F]O=%]$
M>6YA3&]A9&5R`%!,7W1A:6YT960`4&5R;%]N97=84U]F;&%G<P!P97)L7V-O
M;G-T<G5C=`!03%]C=7)S=&%C:VEN9F\`4&5R;%]S=E]S971P=FX`4&5R;%]A
M=E]F971C:`!P97)L7V1E<W1R=6-T`&5N=FER;VX`4&5R;%]M9U]S970`4$Q?
M=&]P7V5N=@!097)L7W-A9F5S>7-M86QL;V,`4&5R;%]N97=35G!V`%!,7V1O
M7W5N9'5M<`!03%]M96UO<GE?=W)A<`!097)L7V-R;V%K`%!E<FQ?;F5W6%,`
M4&5R;%]S>7-?:6YI=#,`4$Q?<&%R<V5R`%!E<FQ?<V%V95]D97-T<G5C=&]R
M7W@`4&5R;%]S=E\R<'9?9FQA9W,`;&EB;2YS;RXU`&QI8F-R>7!T+G-O+C4`
M;&EB=71I;"YS;RXY`&QI8G1H<BYS;RXS`&]P96X`<F5A9`!C;&]S90!?7V5R
M<F]R`&QI8F,N<V\N-P!?7W-T86-K7V-H:U]G=6%R9`!M96UC<'D`<F5A;&QO
M8P!?7W!R;V=N86UE`')E861L:6YK`%]?<W1D97)R<`!R;61I<@!M:V1I<@!S
M=')N8VUP`'-T<FQE;@!O<&5N9&ER`&QS965K`&%T97AI=`!A8V-E<W,`9V5T
M<&ED`&UE;6UO=F4`7U]S=&%C:U]C:&M?9F%I;`!S=')T;VL`8VQO<V5D:7(`
M<W1R;F-P>0!U;FQI;FL`;65M<V5T`%]I;FET7W1L<P!G971U:60`9G!R:6YT
M9@!S<')I;G1F`&UE;6-H<@!L<W1A=`!S=')S='(`<W1R8VUP`')E861D:7(`
M<W1R9'5P`&5X96-V<`!?961A=&$`7U]B<W-?<W1A<G0`7V5N9``O=7-R+VQO
M8V%L+VQI8B]P97)L-2\U+C$T+VUA8V@O0T]210!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S
M97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``>'-?:6YI=`!84U])
M;G1E<FYA;'-?4$%27T-,14%24U1!0TL`<&%R7VUK=&UP9&ER`'!A<E]S971U
M<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV
M`&UA:6X`1D)31%\Q+C`````"``$``0````(``0````(````#`````0`!``$`
M`0`!`````````````0`!```````"``(``0`"``(``@````(````"`````@`"
M`````@`#`````@````(````#``````````(``@````(``@`"``$``@``````
M```"``(``@`!``$````"``,``@`"`````0`"``(``0`"``(````````````"
M``$````!``(````!``$``0````(``@`"``(``0`!``$````````````!``$`
M,@(``!`````@````L"AZ!P```P"A!`````````$``0!6`@``$`````````"P
M*'H'```"`*$$````````8,1@```````%````"0``````````````<,1@````
M```%````$@``````````````@,1@```````%````%P``````````````D,1@
M```````%````'P``````````````F,1@```````%````)@``````````````
MH,1@```````%````*P``````````````J,1@```````%````+P``````````
M````L,1@```````%````-```````````````N,1@```````%````1P``````
M````````P,1@```````%````20```````````````,5@```````%````4```
M````````````$,5@```````%````40``````````````0,5@```````%````
M7@``````````````2,5@```````%````8P``````````````,,)@```````'
M`````0``````````````.,)@```````'````!```````````````0,)@````
M```'````!0``````````````2,)@```````'````!P``````````````4,)@
M```````'````"```````````````6,)@```````'````"@``````````````
M8,)@```````'````$0``````````````:,)@```````'````$P``````````
M````<,)@```````'````%```````````````>,)@```````'````&```````
M````````@,)@```````'````&0``````````````B,)@```````'````&@``
M````````````D,)@```````'````'```````````````F,)@```````'````
M'0``````````````H,)@```````'````'@``````````````J,)@```````'
M````(```````````````L,)@```````'````(0``````````````N,)@````
M```'````(@``````````````P,)@```````'````(P``````````````R,)@
M```````'````)```````````````T,)@```````'````)0``````````````
MV,)@```````'````)P``````````````X,)@```````'````*```````````
M````Z,)@```````'````*0``````````````\,)@```````'````*@``````
M````````^,)@```````'````+````````````````,-@```````'````+0``
M````````````",-@```````'````+@``````````````$,-@```````'````
M,```````````````&,-@```````'````,0``````````````(,-@```````'
M````,@``````````````*,-@```````'````,P``````````````,,-@````
M```'````-0``````````````.,-@```````'````-@``````````````0,-@
M```````'````-P``````````````2,-@```````'````.0``````````````
M4,-@```````'````.@``````````````6,-@```````'````.P``````````
M````8,-@```````'````/```````````````:,-@```````'````/0``````
M````````<,-@```````'````/@``````````````>,-@```````'````/P``
M````````````@,-@```````'````0@``````````````B,-@```````'````
M0P``````````````D,-@```````'````1```````````````F,-@```````'
M````10``````````````H,-@```````'````1@``````````````J,-@````
M```'````2@``````````````L,-@```````'````3```````````````N,-@
M```````'````30``````````````P,-@```````'````3@``````````````
MR,-@```````'````3P``````````````T,-@```````'````4@``````````
M````V,-@```````'````5```````````````X,-@```````'````5@``````
M````````Z,-@```````'````5P``````````````\,-@```````'````6P``
M````````````^,-@```````'````7````````````````,1@```````'````
M70``````````````",1@```````'````7P``````````````$,1@```````'
M````9```````````````&,1@```````'````90``````````````2(/L".CG
M!```Z%(X``!(@\0(PP#_-4:F(`#_)4BF(``/'T``_R5&IB``:`````#IX/__
M__\E/J8@`&@!````Z=#_____)3:F(`!H`@```.G`_____R4NIB``:`,```#I
ML/____\E)J8@`&@$````Z:#_____)1ZF(`!H!0```.F0_____R46IB``:`8`
M``#I@/____\E#J8@`&@'````Z7#_____)0:F(`!H"````.E@_____R7^I2``
M:`D```#I4/____\E]J4@`&@*````Z4#_____)>ZE(`!H"P```.DP_____R7F
MI2``:`P```#I(/____\EWJ4@`&@-````Z1#_____)=:E(`!H#@```.D`____
M_R7.I2``:`\```#I\/[___\EQJ4@`&@0````Z>#^____);ZE(`!H$0```.G0
M_O___R6VI2``:!(```#IP/[___\EKJ4@`&@3````Z;#^____)::E(`!H%```
M`.F@_O___R6>I2``:!4```#ID/[___\EEJ4@`&@6````Z8#^____)8ZE(`!H
M%P```.EP_O___R6&I2``:!@```#I8/[___\E?J4@`&@9````Z5#^____)7:E
M(`!H&@```.E`_O___R5NI2``:!L```#I,/[___\E9J4@`&@<````Z2#^____
M)5ZE(`!H'0```.D0_O___R56I2``:!X```#I`/[___\E3J4@`&@?````Z?#]
M____)4:E(`!H(````.G@_?___R4^I2``:"$```#IT/W___\E-J4@`&@B````
MZ<#]____)2ZE(`!H(P```.FP_?___R4FI2``:"0```#IH/W___\E'J4@`&@E
M````Z9#]____)1:E(`!H)@```.F`_?___R4.I2``:"<```#I</W___\E!J4@
M`&@H````Z6#]____)?ZD(`!H*0```.E0_?___R7VI"``:"H```#I0/W___\E
M[J0@`&@K````Z3#]____)>:D(`!H+````.D@_?___R7>I"``:"T```#I$/W_
M__\EUJ0@`&@N````Z0#]____)<ZD(`!H+P```.GP_/___R7&I"``:#````#I
MX/S___\EOJ0@`&@Q````Z=#\____);:D(`!H,@```.G`_/___R6NI"``:#,`
M``#IL/S___\EIJ0@`&@T````Z:#\____)9ZD(`!H-0```.F0_/___R66I"``
M:#8```#I@/S___\ECJ0@`&@W````Z7#\____)8:D(`!H.````.E@_/___R5^
MI"``:#D```#I4/S___\E=J0@`&@Z````Z4#\____)6ZD(`!H.P```.DP_/__
M_R5FI"``:#P```#I(/S___\E7J0@`&@]````Z1#\__\```````````````!5
M2(GE055,C6\(05132(/L"(L?2&/#A=M,C63'$$R)):RI(`!^.DB+5PA(A=)T
M,4B)%1JD(``/M@*$P'0C2(/"`3PO2(L%!J0@`$@/1,)(B07[HR``#[8"2(/"
M`83`=>&X*,!@`$B%P'0K2(GWZ$+\__^_5%1``.@X_/__Z&_[__^)WTR)XDR)
M[NA"(@``B<?HO_[__^B*_/__Z]:0D)"0@#W9I"```%5(B>5T$.LDD$B#P`A(
MB06EHR``_])(BP6<HR``2(L02(72=>3&!:VD(``!R<,/'T0``&8/'T0``%5(
M@SUGGR```$B)Y706N`````!(A<!T#+\@P&``28G#R4'_X\G#D)"0D)"0D)"0
MD`^V#TB)^(3)="A(BP67-0``2(U7`0^V,$B)^`\?1```0#CQ#[8*2`]$PDB#
MP@&$R77N\\-F#Q]$``!F#Q]$``!!5DB-=SA!54%454B)_5-(@>P(`@``3(U,
M)(A-C8&`````3(G/2(L.2(/&"$B)RDB)R$C!X@A(P>`8)0```/^!X@``_P!(
M"<)(B<A(P>@()0#_``!("<)(B<A(P>@8)?\```!("<)(B<A(P>DH2,'H($B)
M%TC!X`A(B<)(P>`0)0```/^!X@``_P!("<)(B<A(P>D0)0#_``!("<)("<I(
MB5<(2(/'$$PYQP^%=?___TF-26A)C;%H`@``#Q]$``!(BP%(,T'82#-!J$@S
M09A(B<)(`<!(P>H?2`G"@^+_2(E1&$B#P0A(.?%UU$R+=0!(BWPDB$&]W+P;
MCT@#?2!(BTT(3(M5$$B+=1A,B?!,B?)-B?%(P>(%2,'H&TF)R$@)T$R)TDG!
MZ`*#X/]((<I)P>D"2(V\!YEY@EI(B<A(P>$>2/?020G(2"'P08/@_T@#="20
M2`G03(G"`<=,B?!,(?)(]]!(B?E,(=!(P>D;3`-4))A("<)(B?A(P>`%2(VT
M%IEY@EI(B?I("<%,B?!(P>`>`?%)"<%(B?A(B<Y!@^'_2/?02,'N&TPARDPA
MP$@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DCWT$G!Z@)(P><>
M3`-$)*!)"?I,(<A(B?=!@^+_2,'O&TP#3"2H3"'22`G02(GR38V$`)EY@EI(
MB?!(P>`%2`G'2(GP1`''28G(2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I
M&TP#5"2P3"'"2`G02(GZ38V,`9EY@EI(B?A(P>`%2`G!2(GX1`')28GQ2,'F
M'DG!Z0)(]]!)"?%,(<!(B<Y!@^'_2,'N&TPARD@)T$B)RDV-E`*9>8):2(G(
M2,'@!4P#1"2X2`G&2(G(1`'628GZ2,'G'DG!Z@)(]]!)"?I,(<A(B?=!@^+_
M2,'O&TP#3"3`3"'22`G02(GR38V$`)EY@EI(B?!(P>`%2`G'2(GP1`''28G(
M2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I&TP#5"3(3"'"2`G02(GZ38V,
M`9EY@EI(B?A(P>`%2`G!2(GX1`')28GQ2,'F'DG!Z0)(]]!)"?%,(<!(B<Y!
M@^'_3"'*2,'N&TP#1"302`G02(G*38V4`IEY@EI(B<A(P>`%2`G&2(G(1`'6
M28GZ2,'G'DG!Z@)(]]!)"?I,(<A(B?=!@^+_2,'O&TP#3"383"'22`G02(GR
M38V$`)EY@EI(B?!(P>`%2`G'2(GP1`''28G(2,'A'DG!Z`)(]]!)"<A,(=!(
MB?E!@^#_2,'I&TPAPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!R4F)
M\4C!YAY)P>D"2/?020GQ2(G.08/A_TP#5"3@3"'`3"'*2,'N&TP#1"3H2`G0
M2(G*38V4`IEY@EI(B<A(P>`%2`G&2(G(1`'628GZ2,'G'DG!Z@)(]]!)"?I,
M(<A(B?=!@^+_2,'O&TP#3"3P3"'22`G02(GR38V$`)EY@EI(B?!(P>`%2`G'
M2(GP1`''28G(2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I&TPAPD@)T$B)
M^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!R4F)\4CWT$G!Z0)(P>8>3`-4)/A)
M"?%,(<!(B<Y!@^'_2,'N&TP#!"1,(<I("=!(B<I-C90"F7F"6DB)R$C!X`5(
M"<9(B<A$`=9)B?I(P><>2<'J`DCWT$F)\TD)^DPAR$B)]T&#XO](P>\;3`-,
M)`A,(=)("=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>2<'H
M`DCWT$D)R$PAT$B)^4&#X/](P>D;3"'"2`G02(GZ38V,`9EY@EI(B?A(P>`%
M2,'F'DG!ZP),`U0D$$@)P4D)\TB)^$&#X_]$`<E(]]!,(=I(B<Y,(<!)B?E(
MP>X;2`G02,'G'DG!Z0)-C90"F7F"6DB)R$P#1"082,'@!4D)^4B)RD@)QDB)
MR$&#X?](]]!,(<I$`=9,(=A(B?=)B<I("=!(P>$>2,'O&TV-A`"9>8):2(GP
M2<'J`DC!X`5,`UPD($D)RD@)QTB)\$&#XO](B?)(]]!$`<=,(<A)B?!,(=)(
M"=!(P>8>2<'H`DV-G`.9>8):20GP2(GZ2(GX08/@_TP#3"0H2,'@!4C!ZAM(
M"<),B<!,,=!$`=I,`U0D,$@Q^$B)T4V-C`&AZ]EN2(G02,'I&TC!X`5("<%$
M`<E)B?E(P><>2<'I`DB)SDD)^4B)UTC![AM!@^'_2,'O`DR)R$PQP$P#1"0X
M2#'02,'B'DV-E`*AZ]EN2`G72(G(@^?_2,'@!4@)QDB)^$0!UDPQR$P#3"1`
M2#'(2(GR38V$`*'KV6Y(B?!(P>H;2,'@!4@)PD0!PDF)R$C!X1Y)P>@"20G(
M2(G108/@_TC!Z1M,B<!(,?A(`WPD2$@Q\$V-C`&AZ]EN2(G02,'@!4@)P40!
MR4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,B<A,,<!,`T0D4$@QT$B-O`>A
MZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC![P)("==(B?*#Y_](B?A,,<A(P>H;
M3`-,)%A(,<A-C80`H>O9;DB)\$C!X`5("<)$`<))B<A(P>$>2<'H`DD)R$B)
MT4&#X/](P>D;3(G`2#'X2`-\)&!(,?!-C8P!H>O9;DB)T$C!X`5("<%$`<E)
MB?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(3#'`3`-$)&A(,=!(C;P'H>O9
M;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"2`G72(GR@^?_2(GX3#'(2,'J&TP#
M3"1P2#'(38V$`*'KV6Y(B?!(P>`%2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!
M@^#_2,'I&TR)P$@Q^$@#?"1X2#'P38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ
M2,'F'DG!Z0))"?%(B<Y!@^'_2,'N&TR)R$PQP$P#A"2`````2#'02(V\!Z'K
MV6Y(B<A(P>`%2`G&`?Y(B==(P>(>2,'O`D@)UTB)\H/G_TB)^$PQR$C!ZAM,
M`XPDB````$@QR$V-A`"AZ]EN2(GP2,'@!4@)PD0!PDF)R$C!X1Y)P>@"20G(
M2(G108/@_TC!Z1M,B<!(,?A(`[PDD````$@Q\$V-C`&AZ]EN2(G02,'@!4@)
MP40!R4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,B<A,,<!,`X0DF````$@Q
MT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC![P)("==(B?*#Y_](B?A,
M,<A(P>H;3`.,)*````!(,<A-C80`H>O9;DB)\$C!X`5("<)$`<))B<A(P>$>
M2<'H`DF)TDD)R$B)T4G!Z@)!@^#_2,'I&TR)P$@Q^$@#O"2H````2#'P38V,
M`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))B<Q)"?%(B<Y!@^'_2,'N
M&TR)R$PQP$P#A"2P````2#'02,'B'DB-O`>AZ]EN20G22(G(08/B_TC!X`5(
M"<9,B=`!_DPQR$G![`)(,<A(P>$>2(GR38V$`*'KV6Y)"<Q(B?!!@^3_3`.,
M)+@```!(P>`%2,'J&TB)\TB+C"3(````2`G"3(G@2,'K`DPQT$0!PDP#E"3`
M````2#'P2,'F'DB)UTV-C`&AZ]EN2`GS2(G0@^/_2,'@!4C![QM("<=(B=A)
MB=-,,>!$`<])P>L"2#'02,'B'DF)^$V-E`*AZ]EN20G32(GX08/C_TC!X`5)
MP>@;20G`3`'I3(G810'03(G:3`'A2`G82"':3(G&2"'X28GY2,'N&T@)T$C!
MYQY)P>D"2`'!3(G`20GY2,'@!4&#X?]-B<)("<9,B<A,B<H!SDB+C"30````
M3`G83"':3"'`2(GW2`G02,'O&TG!X!Y,`>E)P>H"0;S6P6+*2`'930G"2`'!
M2(GP08/B_TC!X`5,B=)("<=,B=`!STB+C"38````3`G(2"'P28GX3`'I3`'9
M3"'*28GS2`G02,'F'DG!Z!M(`<%(B?A)P>L"2,'@!4D)\TD)P$&#X_]!`<A(
MBXPDX````$R)V$P)T$R)VDR)QDPATD@A^$C![AM,`>E("=!,`<E)B?E(P><>
M2`'!3(G`2<'I`DC!X`5)"?E("<9!@^'_`<Y(BXPDZ````$R)R$P)V$R)RDB)
M]TPAVDPAP$P!Z4@)T$P!T4V)PD@!P4B)\$C![QM(P>`%2<'@'DG!Z@)("<=-
M"<(!ST&#XO](BXPD\````$R)T$R)TDF)^$P)R$PARDG!Z!M,`>E((?!("=!,
M`=E)B?-(`<%(B?A(P>8>2,'@!4G!ZP))"<!)"?-!`<A!@^/_2(N,)/@```!,
MB=A,B=I,B<9,"=!,(=)(P>X;3`'I2"'X2`G03`')28GY2`'!3(G`2,'@!4@)
MQ@'.2,'G'DG!Z0))"?E(BXPD``$``$B)]T&#X?](P>\;3(G(3(G*3`G83"':
M3`'I3"'`3`'138G"2`G02<'@'DG!Z@)(`<%(B?!-"<)(P>`%08/B_T@)QTR)
MT$R)T@'/2(N,)`@!``!,"<A,(<I((?!)B?A("=!)P>@;3`'I3`'928GS2,'F
M'D@!P4B)^$G!ZP)(P>`%20G`00'(20GS2(N,)!`!``!!@^/_3(G&3(G83(G:
M2,'N&TP)T$PATDP!Z4@A^$P!R4F)^4@)T$C!YQY)P>D"2`'!3(G`20GY2,'@
M!4&#X?]("<9,B<A,B<H!SDB+C"08`0``3`G83"':3"'`2(GW2`G02,'O&TP!
MZ4P!T4V)PDG!X!Y(`<%(B?!)P>H"2,'@!4T)PD@)QT&#XO\!STB+C"0@`0``
M3(G03(G228GX3`'I3`'93`G(3"'*2"'P28GS2<'H&T@)T$C!YAY)P>L"2`'!
M2(GX20GS2,'@!4&#X_])"<!,B=A,B=I!`<A(BXPD*`$``$P)T$PATD@A^$R)
MQD@)T$C![AM,`>E,`<E)B?E(P><>2`'!3(G`2<'I`DC!X`5)"?E("<9!@^'_
M`<Y(BXPD,`$``$R)R$P)V$R)RDB)]TPAP$P!Z4P!T4PAVDV)PD@)T$G!X!Y(
MP>\;2`'!2(GP2<'J`DC!X`5-"<)("<=!@^+_`<](BXPD.`$``$R)T$P)R$R)
MTDF)^$PARD@A\$G!Z!M,`>E("=!,`=E)B?-(P>8>2`'!2(GX2<'K`DC!X`5)
M"?-)"<!!@^/_00'(2(N,)$`!``!,B=A,"=!,B=I,B<9,(=)((?A,`>E("=!,
M`<E)B?E(`<%,B<!(P>X;2,'@!4C!YQY)P>D"2`G&20GY`<Y!@^'_2(N,)$@!
M``!,B<A,B<I(B?=,"=A,(=I(P>\;3`'I3"'`2`G03`'138G"2`'!2(GP2<'@
M'DC!X`5)P>H"2`G'30G"`<]!@^+_2(N,)%`!``!,B=!,B=))B?A,"<A,(<I)
MP>@;3`'I2"'P2`G03`'928GS2`'!2(GX2,'@!4D)P$$!R$C!YAY)P>L"20GS
M2(N,)%@!``!,B<9!@^/_2,'N&TR)V$R)VDP!Z4P)T$PATDP!R4@A^$F)^4@)
MT$C!YQY)P>D"2`'!20GY3(G`08/A_TP#K"1@`0``2,'@!4@)QDR)R$R)RDP)
MV$PAV@'.3"'`2(GW2`G030'52,'O&TD!Q4B)\$V)PDC!X`5)P>`>2<'J`D@)
MQTB+E"1H`0``1`'O30G"28GP08/B_TB)^4G!Z`),B=!,`>)(P>D;3#'(3`':
M2#'P2,'F'D@!PDB)^$D)\$C!X`5!@^#_2`G!3(G``=%(BY0D<`$``$PQT$@Q
M^$B)SDC![AM,`>),`<I)B?E(P><>2`'"2(G(2<'I`DC!X`5)"?E("<9!@^'_
M`=9(BY0D>`$``$R)R$PQP$B)]T@QR$P!XDP!TDF)RD@!PDB)\$C![QM(P>`%
M2,'A'DG!Z@)("<=)"<H!UTB+E"2``0``08/B_TR)T$B)^4PQR$C!Z1M,`>)(
M,?!,`<))B?!(P>8>2`'"2(GX2<'H`DC!X`5)"?!("<%!@^#_`=%(BY0DB`$`
M`$R)P$PQT$B)SD@Q^$C![AM,`>),`<I)B?E(P><>2`'"2(G(2<'I`DC!X`5)
M"?E("<8!UDB+E"20`0``08/A_TR)R$B)]TPQP$C![QM,`>)(,<A,`=))B<I(
MP>$>2`'"2(GP2<'J`DC!X`5)"<I("<=!@^+_`==(BY0DF`$``$R)T$PQR$B)
M^4@Q\$C!Z1M,`>),`<))B?!(P>8>2`'"2(GX2<'H`DC!X`5)"?!("<%!@^#_
M`=%(BY0DH`$``$R)P$PQT$B)SD@Q^$C![AM,`>),`<I)B?E(`<)(B<A(P>`%
M2,'G'DG!Z0)("<9)"?D!UDB+E"2H`0``08/A_TR)R$B)]TPQP$C![QM,`>)(
M,<A,`=))B<I(P>$>2`'"2(GP2<'J`DC!X`5)"<I("<=!@^+_`==(BY0DL`$`
M`$R)T$PQR$B)^4@Q\$C!Z1M,`>),`<))B?!(P>8>2`'"2(GX2<'H`DC!X`5)
M"?!("<%!@^#_`=%(BY0DN`$``$R)P$B)SDP!XDPQT$C![AM(,?A,`<I)B?E(
M`<)(B<A(P><>2,'@!4G!Z0)("<9)"?D!UDB+E"3``0``08/A_TR)R$B)]TPQ
MP$C![QM,`>)(,<A,`=))B<I(P>$>2`'"2(GP2<'J`DC!X`5)"<I("<=!@^+_
M`==(BY0DR`$``$R)T$PQR$B)^4@Q\$C!Z1M,`>),`<))B?!(`<)(B?A(P>`%
M2`G!2,'F'DG!Z`(!T4D)\$B+E"30`0``08/@_TB)SDR)P$C![AM,`>),,=!(
M,?A,`<I)B?E(`<)(B<A(P><>2,'@!4G!Z0)("<9)"?D!UDB+E"38`0``08/A
M_TR)R$B)]TF)\TPQP$C![QM,`>)(,<A,`=))B<I(P>$>2`'"2(GP2<'J`DC!
MX`5)"<I("<=!@^+_`==(BY0DX`$``$R)T$B)^4B)^TP!XDP!PDPQR$C!Z1M(
M,?!)P>L"2,'F'D@!PDB)^$D)\TC!X`5!@^/_2,'K`D@)P4R)V`'12(N4).@!
M``!,,=!(,?A)B<A(P><>2<'H&T@)^TP!XH/C_TP!RDF)R4@!PDB)R$C!X`5)
M"<!(B=A!`=!(BY0D\`$``$PQV$@QR$R)QTR)QDC![QM,`>),`=)(`<),B<!(
MP>`%2`G'`==(P>$>2<'I`DD)R4B+E"3X`0``2,'N`D&#X?](B?E,B<A(P>D;
M3`'B2#'83`.D)``"``!,,<!,`=I)P>`>2`'"3`G&2(GX2,'@!8/F_T@)P4B)
M\$D!W$PQR`'12#'X2(G*20'$2(G(2,'B!4C!Z!M("=!$`>!$`?!(B44`2(GX
M2,'G'DC!Z`(#30A("?@#11`#=1A$`TT@2(E-"$B)11!(B7483(E-($B!Q`@"
M``!;74%<05U!7L-,B60DX$R)?"3X28G\2(E<)-!(B6PDV$F)]TR);"3H3(ET
M)/!(@^PX2(7_=24QP$B+7"0(2(ML)!!,BV0D&$R+;"0@3(MT)"A,BWPD,$B#
MQ#C#3(LU-Y(@`$V%]G3/#[8'A,!U!#'`ZQ<\/4B)^G3U2(/"`0^V`H3`=46)
MT$0IX$F++DB%[72E3&/H3(GS9I!,B>I,B>9(B>_H9N;__X7`=0I)C40M`(`X
M/70:2(MK"$B#PPA(A>UUU^EO____9I`\/76LZ[5,*?-(@\`!2,'[`T&)'^E6
M____#Q^``````%532(G[2(/L&$B-;"049I`QP$B)[DB)W^@#____2(7`="9(
M8T0D%$B-%,4`````2`,5>I$@`$B#P@A(BP)(A<!(B4+X=?#KR$B#Q!A;7<.0
M2(/L&#'`2(UT)!3HP/[__TB#Q!C##Q]$``!F#Q]$``!(@^P(@SW5BR``_W0+
MBP7-BR``2(/$",,QP+]H5$``Z+S___](A<!T!P^V`(3`=1,QP(D%J(L@`(L%
MHHL@`$B#Q`C#/#`/E<`/ML#KY0\?`$B#[`B______^A&Y/__,?:_T#A``$B#
MQ`CIUN;__V:02(L%V8L@`%,Q]K\%5D``2(M("$B+!:Z+(``/MU`@#[8%>XL@
M`&:!XO\!@^!_P>('"<)FB5$"2(L%HXL@`$B+6`CH_N7__TB)0RA(BP6/BR``
M2(M0"$B+!72+(`!(B4(P2(L%>8L@`#'22(M("$B+!02,(`!(A<!T!TB+D*@`
M``!(B5$X2(L%58L@`$B+0`A(QT!``````$B+!4*+(`!(BT`(2,=`(`````!(
MBP4OBR``2(M0"$B+!2R+(`!(B4)(6\,/'X``````#Q^``````$R)9"3H2(E<
M)-A)B?Q(B6PDX$R);"3P3(ET)/A(@>RH````2(7_=`6`/P!U,TB+G"2`````
M2(NL)(@```!,BZ0DD````$R+K"28````3(NT)*````!(@<2H````PP\?`.BO
MY/__2(7`2(G%=,`/'P!(B>_HK.+__TB%P`^$H0```$B-6`B_<U1``+D"````
M_$B)WO.F=-F_<E1``+D#````2(G>\Z9TR$R)Y^@DX___2(G?28G%Z!GC__]!
MC40%`DAC^.A\X?__2(G92(G'28G%3(GBOG540``QP.BTXO__2(GF3(GOZ$GB
M__^#P`%T$0^W1"0()0#P```]`$```'0V3(GOZ`OB__],B>_HD^3__TB)[^@+
MXO__2(7`#X5?____2(GOZ+KD__],B>?H,N/__^GV_O__3(GOZ,'^__^0Z\</
M'X``````#Q^``````%-(B?M(@\2`2(GFZ-3B__^%P'48#[=$)`@E`/```#T`
M0```=`\]`*```'0(2(/L@#'`6\-(B=^^`@```.@CX___A<`/E,!(@^R`6P^V
MP,.02(E<).A(B6PD\$R)9"3X2('L.`@``$B-G"00!```2(L%6XD@`$B)A"08
M"```,<#H<./__[D95D``B<*^>U1``#'`2(G?Z*KA__^%P'DV,>U(BY0D&`@`
M`$@S%2&)(`!(B>AU8$B+G"0@"```2(NL)"@(``!,BZ0D,`@``$B!Q#@(``##
M2(G?N@`$``!(B>;H4.#__X7`B<-XM(UX`4AC_^C_W___2(7`=*1(8]M(B<5(
MB>9(B=I(B<?HQN+__\8$*P#KC.AKXO__#Q^``````.DK____#Q]$``!F#Q]$
M``!!5S'`059)B?Y!54%454B)]5-(@^P8@#X]#Y3`2`'%2(GOZ"WA__](C70D
M%$&)QTR)]S'`Z+?Z__](A<!(B<-T-TB)Q^@+X?__1(GZ2#G0#X*\````#[9%
M`$B#Q0&(`TB#PP&$P'7N2(/$&#'`6UU!7$%=05Y!7\-(BST!C2``13'DN!``
M``!(@S\`=!](B?I(BT((08/$`4B#P@A(A<!U[T&-1"0"2)A(P>`#BQ6.B"``
MA=(/A1`!``!(B<?'!7F((``!````Z/C>__](A<!)B<4/A!D!``!)8\1(BS6>
MC"``3(GO2(T<Q0````!(B=KH7^+__TR)+82,(`!(BP5]C"``2,=$`P@`````
M1(ED)!1!#[863(GPA-(/A8@```"+7"0412GW08U\!P)(P>,#2`,=28P@`.B(
MWO__2(7`2(D##X2I````BU0D%$B+!2V,(`!(BQ3000^V!H3`B`)T)3P]="%,
MB??K#F8/'T0``$B#QP$\/70.#[9'`4B#P@&$P(@"=>K&`CT/'X``````#[9%
M`$B#Q0&(0@%(@\(!A,!U[>F__O__@/H]#X1O____2(/``0^V"(3)#X1@____
M@/D]=>SI5O___TB)Q@\?`.B?X/__2(7`2(D%H8L@`'0026/$2(T<Q0````#I
M"____TB#Q!BX_____UM=05Q!74%>05_##Q]$``!F#Q]$``!!5T%628G^055!
M5$&\D51``%532(/L2$R+/4(8``!)B>5(QP0DD51``$C'1"0(AU1``$C'1"00
ME%1``$C'1"08BE1``$C'1"0@CU1``$C'1"0HH51``$C'1"0P`````.L>3(GV
M3(GG,<#H@OW__TV+90A)@\4(387D#X2)````,<!,B>?HA_G__TB%P$B)Q730
M@#@`=,M,B?9(B<?H`^#__TB%P'7(3(GWZ);>__],B?](B</HB][__TB-7`,!
M2(GOZ'[>__](C3P#Z.7<__])B>A(B<=(B<-,B?E,B?*^P%5``#'`Z!K>__],
MB><QP$B)WNCY_/__38ME"$F#Q0A-A>0/A7?___](@\1(6UU!7$%=05Y!7\-F
M#Q^$``````!(@^PXOZQ40`!(BP5@A2``2(E$)"@QP$B+!?(6``!(B00D2(L%
M[Q8``$B)1"0(2(L%ZQ8``$B)1"002(L%YQ8``$B)1"08#[<%XQ8``&:)1"0@
M,<#H1_C__S'`O[540`#H._C__S'`O[U40`#H+_C__S'`O\940`#H(_C__S'`
MO\U40`#H%_C__S'`O]U40`#H"_C__S'`O^E40`#H__?__S'`OVA40`#H\_?_
M_S'`O_)40`#HY_?__S'`O_Q40`#HV_?__S'`OP950`#HS_?__S'`OQ-50`#H
MP_?__S'`OQQ50`#HM_?__S'`OR=50`#H^_?__TB%P'0/2(G&O_)40``QP.C'
M^___,<"_.%5``.C;]___2(7`=`](B<:_2E5``#'`Z*?[__\QP+]554``Z+OW
M__](A<!T-DB)QK_I5$``,<#HA_O__S'`OH%50`"_S51``.AV^___2(M$)"A(
M,P4*A"``=5%(@\0XPP\?`#'`OV550`#H=/?__TB%P'012(G&OVA40``QP.A`
M^___Z[=(C70D$;]V54``N0H```#\\Z9UHTB-="0;OVA40``QP.@9^___ZY#H
M9MW__V:02(/L".C+W/__B<?HY-K__S'22(7`=`-(BQ!(B=!(@\0(PP\?@```
M```/'X``````55-(B?M(@^P(2(7_=`@/MB]`A.UU$$B#Q`B_<U1``%M=Z:[;
M___H"=S__T@!V$B-4/](.=,/@YX```!(BST&%0``#[9`_P^V-T`X\'0)ZRH/
MM@HXP75F2(/J`4@YTV:0<NY(.=IU*4`Z+W2J2(/$"%M=Z5W;__\/M@)`.,9T
MXTB#Z@%(.=-R[^O89@\?1```2(/J`4@YTW,)#[8".@=FD'3N2"G:,<E(C4("
M2#T`!```=@Y(@\0(2(G(6UW#B<CKN4B#P@%(B=Z_@,5@`.A2W/__N8#%8`#K
MVDB+/6@4``#K@`\?@``````/'X``````2(E<)/!(B6PD^$B#[!A(B?OH^O[_
M_TB)Q^B2WO__2(G%,<#H"/;__X7`=`I(A=MT!8`[`'4/2(M<)`A(BVPD$$B#
MQ!C#OH-50`!(B>_H4MS__T@YQ77?2(G?2(ML)!!(BUPD"$B#Q!CI`_?__P\?
M`%-(@^P@B7PD'$B)="002(U\)!Q(B50D"$B-="002(U4)`CHG=S__X`],H(@
M```/A"D!``"+1"0<@`VA@2```X/`!4ACR$B%R0^(2@$``/)(#RK!\@]8!7UP
M``!F#RX%?7````^'3`$``$B-/,T`````Z.[;__](BW0D$$B)P4B)!7.&(`!,
MC4GX2(L&2,=!"(A50`!(B0%(BP7Z@"``2,=!&(M50`!(B4$01(M$)!S'!3>&
M(``$````08/X`7XF3(U)^+\!````N@@````/'P!(BP06@\<!2(E$"AA(@\((
M03GX?^M!C4`$OO!30`!%,<!(F$G'!,$`````BU0D'$B+/=J%(`"#P@/H9MC_
M_X7`B<-T<4B+/<6%(`#HA-K__S'`O]U40`#H=/3__TB%P'092(L]J(4@`.@7
MV/__Z'+9__^)V$B#Q"!;PTB+/9>%(`!(A?]T<.@U_O__Z]0/'P#HW]C__TB%
MP$B)QTB)!6Z%(`!T=.B;V?__Q@5`@"```.FO_O__2(L]5(4@`.@3V/__B</I
M?/___TB)R$B)RDC1Z(/B`4@)T/)(#RK`\@]8P.F>_O__OA#%8`"_A%1``#'`
MZ,[:__^_Z51``.C0\___2(7`2(G'2(D%"X4@``^%<____^E)____0+<!Z)3:
M__]!5T%6055!5$F)_+_I5$``55-(B?-(@>RH!```2(L%#8`@`$B)A"28!```
M,<#H?O/__TB++;\1``!,B>=)B<5(B>[H_=G__TB%P'0Y3(GFOP950``QP.@U
M]___2(N4))@$``!(,Q7&?R``3(G@#X4T`0``2('$J`0``%M=05Q!74%>05_#
M3(GGZ%?8__],BSUL$0``2(G?08G&3(G^Z&+7__](A<!(B<-THD&#Q@%$B70D
M#$R-M"20````#Q]$``"`.P"X<U1``$@/1-A-A>UT#TB)WDR)[^@HVO__A<!T
M?DB)W^C\U___B<%(F`^V1`/_.D4`=1V-0?](F$B-%!B0#[9"_\8"`(/I`4B#
MZ@$Z10!T[8M$)`P!R#W_`P``#X\H____38G@2(GI2(G:OL!50`!,B?<QP.AH
MU___2(UT)!!,B??H^];__X7`=1$/MT0D&"4`\```/0"```!T&S'_3(G^Z)S6
M__](A<!(B<,/A4S____IT_[__[X!````3(GWZ#[8__^%P'743(GVOP950`#H
M^?7__TR)]^CEUO__28G$Z;3^___H.-C__P\?0`!!5TF)_[_I5$``059!54%4
M55-(@>SH@0``2(L%8'X@`$B)A"38@0``,<!(QX0DT````(Y50`!(QX0DV```
M`)-50`!(QX0DX`````````#HK?'__TB%P$B)PW0)@#@`#X6/`@``,<!(C:PD
MT````.A=^O__2(7`2(G##X3'`0``2(G?Z*W6__](C7P``>@3U?__@#L`28G%
M="9(B<4/'T``#[832(GO,<"^HU5``$B#PP%(@\4"Z#K6__^`.P!UX4B-K"2@
M````OTI50`!(QX0DH````$I50`!(QX0DJ````$-50`!(QX0DL````*A50`!(
MQX0DN````&!50`!(QX0DP````+!50`!(QX0DR`````````#K$4B+?0A(@\4(
M2(7_#X1.`0``,<#HTO#__TB%P$B)PW3@@#@`=-M(B<?H;?/__X7`=,](B=_H
MA=7__TB%P$F)Q`^$'0$``$R)Y^C1U?__3(GO2(G#Z,;5__^-A`,$!```2&/H
M2(GOZ"34__](BQ7!#@``2(G'28G&38GI0;B#54``OKY50``QP$B)T4B)5"00
M3(GBZ$?5__^^P`$``$R)]^CZU?__@\`!#X1(`0``2(UT)"!,B??HQ-7__X7`
M=14/MT0D*"4`\```/0!````/A%@!``!)BQ=(BST-?2``3(GQOMA60``QP#'M
MZ.#4__](BY0DV($``$@S%6U\(`!(B>@/A7,"``!(@<3H@0``6UU!7$%=05Y!
M7\-(B<?HGM3__TB)PTB#Q0A(A=L/A3G^__](BWT`2(7_#X0R`@``,<#HIN__
M_TB%P'3:@#@`=<I(@\4(2(7;=-D/'P#I"O[__T4QY(`]]0P```!(QX0D\```
M`+150`"[M%5``$C'A"3X````<U1``$C'A"0``0```````$B-K"3P````=2CI
MI/[__TV%Y`^%F_[__TB+70A(A=L/A([^__](@\4(@#L`#X2!_O__2(G?Z,[Q
M__^%P'312(G?Z.;3__])B<3KQ$B)Q^CU]/__2(G?Z-'3__](B<7I^?[__^A4
MU?__@S@1#X2J_O__Z$;5__])BQ=$BP!,B?%(BSW2>R``OIA60``QP#'MZ*C3
M___IP_[__XM<)"SH6M3__SG##X67_O__#[=$)"@E_P$``#W``0``#X6"_O__
M2(GOZ#72__^_BE1``$B)Q3'`Z(+N__](A<!(B<</A`L!``#H1=/__TF+/TB)
MQNBV^O__2(7`28G$#X3O````3(GGZ(;3__^#^`-!B<`/CV4%```QP.A?[O__
MA<!U%C'V3(GGZ"72__^%P(E$)!P/A<(```"^@55``+]H5$``,<#H]/'__^BS
MU/__2(M,)!!!B<!!N0560`!,B?*^X%5``$B)[S'`,=OHX=+__^LZZ$K4__^#
M.!$/'P!U/^A]U/__2(M,)!"#PP%!B<!!B=E,B?*^[E5``$B)[S'`2,<$)`56
M0`#HI=+__[[``0``2(GOZ%C3__^#P`%TM$R)]^B;U/__2(GNO^E40``QP.AH
M\?__2(GOZ'#S___I?_W__[N<54``Z?#[__^0Z)_3__]-BR?I"?___[H"````
M2,?&[O___XG'Z'32__^+?"0<2(VT)!`!``"Z!@```.B.TO__@+PD$`$```!U
M#H"\)!$!``!##X38!```BWPD'#'V,=),C:0D$($``.@QTO__OXFKS>^^_MRZ
MF+GPX=+#2,>$)!"!```!(T5G2(F\)!B!``!)@\0X2(FT)""!``!(QX0D*($`
M`'94,A!(B8PD,($``$C'A"0X@0```````$C'A"1`@0```````,>$)(B!````
M````BWPD'$B-M"00`0``N@"```#HY='__X7`08G%#XXZ`0``2(N,)#B!``!)
M8]5(BX0D0($``$B-G"00`0``C3312#G.2(FT)#B!``!(@]``2,'J'4B)A"1`
M@0``2`&4)$"!``"+E"2(@0``A=)T:>F%````#Q]$``!(BP-(C;PD$($``$&#
M[4!(B80D2($``$B+0PA)B40D"$B+0Q!)B40D$$B+0QA)B40D&$B+0R!)B40D
M($B+0RA)B40D*$B+0S!)B40D,$B+0SA(@\-`28E$)#CHL=3__T&#_3]_FTEC
MU4B)WDR)Y^A!TO__1(FL)(B!``#I"?___[A`````2&/Z2(VT)!`!```IT$F-
M/#Q!.<6)PT$/3MU,8_M,B?KH"M+__XG8`X0DB($``(/X0(F$)(B!```/A<;^
M__](C8PD$`$``$$IW4B-O"00@0``28T<#^@QU/__Z7O___^+?"0<Z$?0__](
MBYPD.($``$R+I"1`@0``2(G82,'H`X/@/TACT(/``8/X.,:$%$B!``"`#XZG
M`@``2&/XND`````Q]BG"2(V\/$B!``!(8]+HJM'__TB-O"00@0``Z,G3__](
MC;PD$($``+D'````,<#\2(/'./-(JTR)X$B-O"00@0``1(BD)(.!``!(P>@8
MB)PDAX$``$R-O"20@0``B(0D@($``$R)X$R-K"3`@0``2,'H$(B$)(&!``!,
MB>!-B?Q(P>@(B(0D@H$``$B)V$C!Z!B(A"2$@0``2(G82,'H$(B$)(6!``!(
MB=@QVTC!Z`B(A"2&@0``Z"W3__](BY0D$($``$B)T(B4),.!``!(P>@8B(0D
MP($``$B)T$C!Z!"(A"3!@0``2(G02(N4)!B!``!(P>@(B(0DPH$``$B)T(B4
M),>!``!(P>@8B(0DQ($``$B)T$C!Z!"(A"3%@0``2(G02(N4)""!``!(P>@(
MB(0DQH$``$B)T(B4),N!``!(P>@8B(0DR($``$B)T$C!Z!"(A"3)@0``2(G0
M2(N4)"B!``!(P>@(B(0DRH$``$B)T(B4),^!``!(P>@8B(0DS($``$B)T$C!
MZ!"(A"3-@0``2(G02(N4)#"!``!(P>@(B(0DSH$``$B)T(B4)-.!``!(P>@8
MB(0DT($``$B)T$C!Z!"(A"31@0``2(G02,'H"(B$)-*!``!"#[84*TR)YS'`
MOJ-50`!(@\,!28/$`N@(SO__2(/[%'7>QH0DN($```!!N0560`!-B?A(BTPD
M$$R)\K[154``2(GO,<#HVLW__^E"^___2)B_QU5``$F-=`3\N`4```#\2(G!
M\Z8/A7[Z__]!@_@$=!E!C4#\2(M4)!!(F$$/MD0$_SH"#X5?^O__28M?"$B%
MVP^$4OK__TB)W^C$S?__2(/X`P^&0/K__TB-=`/\O\Q50`"Y!0```/SSIDP/
M1./I)?K__[HX````2&/X,?8IPDB-O#Q(@0``2&/2Z`//___I>/W__X"\)!(!
M``!!#X4:^___@+PD$P$``$,/A0S[__^`O"04`0``2`^%_OK__X"\)!4!``!%
M#X7P^O__BWPD'+H"````2,?&QO___^@AS?__BWPD'$B-M"00`0``NBD```#H
M.\W__TR-A"00`0``0;D%5D``Z=?^__\/'T``05:_S51``$%505154TB![!`$
M``#&!1UT(``!2(L%+G0@`$B)A"0(!```,<#HG^?__TB%P'0)@#@Q#X3;`0``
M,<#HFN[__[H+````O@$```"__U5``.B:R___2(7`#X2#````,>V#/;1X(``!
M2(M`$$R+8"A^7[L(````ZRT/'P!(BW<02(L%G7@@`$B+/!CHD,[__X7`=3V#
MQ0%(@\,(C44!.05X>"``?BLQTHGN3(GGZ`[-__](A<!T&DB+./9'#01UO#'V
MN@(```#H=,[__TB)QNNOBQ5%>"``C4+_.>@/A`X!``"Z!````+X!````OP16
M0`#H^LK__TB%P$B)PW0B2(M`$+X&5D``2(LXZ/'*__](BT,02(LX]D<.0`^%
M!P$``+H$````O@$```"_)55``.B\RO__2(7`2(G#="<QP+\&54``Z(3F__](
MA<!(B<(/A`@!``!(BT,02(G62(LXZ)W*__\QP+_I5$``Q@7#<B```$C'!:!R
M(```````Z$OF__](A<!(B06)=R``#X2E````OL`!``!(B<?HXLO__X7`=25(
MBX0D"`0``$@S!9MR(``/A1\!``!(@<00!```6UU!7$%=05[#@_@1=-:#^/]T
MT8G!2(L%2G<@`$B+%3-W(`"_@%=``$B+,#'`Z-#,__^#Z@$/CNG^__^[`0``
M`$R)YX/#`>C7R?__.1T-=R``?^WIS/[__X!X`0!FD`^$(/[__^D4_O__#Q]$
M``#HW\O__^GJ_O__2(L]YW8@`.B*\___2(7`2(D%R'8@``^%CP```+\P5T``
MZ&3,__](BP7!=B``NO\#``!(B>:_"U9``$R+,$B+0Q!,BRCH,<G__X7`B<)^
M.(/J`4ACZH`\+`!U0(72?BA(B>J^+P```$B)Y^BKRO__2(7`=!-(B>I(B>9,
MB>_H^,K__^FF_O__3(GV3(GOZ#C)__\/'T``Z9+^__](8^CKOV8/'T0``.@?
MR___2(M#$$B++3AV(`!(BSCV1PT$=#I(BW\02(GNZ"_)__^)Q4B+0Q!(BSCV
M1PT$=#!(BT<02(G"2(L%!G8@`(GIOUA70`!(BS`QP.B1R___N@(````Q]N@%
MS/__2(G'Z[FZ`@```#'VZ/3+___KQ@\?@``````/'X``````NAY60`"^A!U`
M`+\H5D``Z7#+__]F#Q]$``!F#Q]$``!(@^P(Z-?___^Y!59``$4QP+YP4$``
M2(G*OT160`!(@\0(Z8W)__^0D)"0D)"0D)!52(GE4TB#[`A(BP70:R``2(/X
M_W05,=O_T$B+@_B_8`!(@^L(2(/X_W7M2(/$"%O)PY"02(/L".@3S/__2(/$
M",,```````!005)?0TQ%04X`+BX`)7,O)7,`+W!R;V,O)6DO)7,`3$E"4$%4
M2`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?5$5-4`!005)?1$5"54<`4$%27T-!0TA%`%!!4E]04D]'3D%-10!0
M05)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!
M3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!
M3%]#3$5!3@!005)?0TQ%04X]`#$`<&%R+0`M90`M+0!54T52`%5315).04U%
M`%-94U1%30`E,#)X`%1%35!$25(`5$U0`"]V87(O=&UP+P`E<R5S)7,E<P!P
M87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M
M<"TE=2TE=25S`$%21U8`&`!P97)L`"]P<F]C+V-U<G!R;V,O9FEL90!P97)L
M>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ
M4$%2.CI"3T]4`#H```````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@(```````````O%5```````!95D```````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!E
M>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```````````C(2]U<W(O8FEN+W!E<FP*979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P[
M"@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@
M870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3@*
M"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`[
M"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE
M.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@
M(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B
M96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@
M(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R
M7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H
M:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T
M;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA
M=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@
M(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N
M(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M
M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI
M<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN
M9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@
M(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%
M(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^
M("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*
M"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I
M"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@
M)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P
M+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE
M;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T
M;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A
M=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I
M"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"
M14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET
M7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6
M>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%2
M1U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@
M)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6
M*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*
M("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX
M("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@
M*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S
M971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I
M;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[
M>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L
M(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@
M("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L
M("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN
M(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@
M9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@
M("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@
M;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@
M("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X
M="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@
M("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D
M8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@
M(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B
M=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@
M("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D
M('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D
M14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T
M<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@
M)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B
M:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@
M("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@
M("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL
M;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?
M1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@
M/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@
M("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@
M("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO
M9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@
M("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@
M("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@
M("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E
M96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M
M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@
M("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D
M;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[
M8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE
M("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E
M='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)
M3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@
M("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@
M<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@
M(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@
M("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M
M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S
M="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA
M;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L
M97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@
M*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R
M97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I
M=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L
M87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C
M97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D
M;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PHC($1O
M;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE
M<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M
M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@
M("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A
M<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R
M"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A<'!N
M86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'4D%-($!04D]'7T%21U8B
M+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@8V]D
M92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I='-E
M;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O;FUE
M;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M
M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6.PH@("`@("`@("1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*("`@('T*("`@(&5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@("`@("!M>2!`861D7W1O
M7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`@("`@)$%2
M1U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*
M"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@("`@
M('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@("`@(&5V86P@
M(G5S92`D,B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M3R<I('L*("`@("`@("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@
M("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@("`@("1B=6YD
M;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@
M("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`@("`@)&-A
M8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<VAI
M9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C
M;61[)#%]*2!["B`@("`@("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%
M35`G?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@
M("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@("`@("9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`@
M("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@
M("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@6%A8
M("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T
M(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@
M("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D
M("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I
M92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R
M;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@
M("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@
M("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@
M("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@
M("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*
M("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO
M="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@
M("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I
M;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I
M;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$[
M"B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P
M;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`[
M"B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@
M("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT
M.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI
M("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@
M+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*
M("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H
M+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*
M("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD
M;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC
M*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`
M:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T
M:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*
M("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET
M92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@(R!&
M:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@
M("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O
M0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI
M<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T
M:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G
M:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L
M"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F
M:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S
M>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R
M('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@
M("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M
M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D
M9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<
M+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA
M7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS
M:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@
M(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B
M+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0[
M"B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@
M("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG
M+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@
M("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N
M=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@
M("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@
M(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@
M("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@
M("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@
M("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N
M9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@
M/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE
M=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*
M("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U
M+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@
M*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@
M("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^
M861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D
M8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A
M8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2
M+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T
M.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R
M;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D[
M"@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O
M(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L
M;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7
M:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E
M<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@
M("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`
M(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*
M"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%
M35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@
M(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@
M("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@
M("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@
M("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@
M("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@
M("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@
M("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@
M("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@
M("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*
M("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@
M("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M
M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP
M<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A
M="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@
M(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]
M"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@
M>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@
M("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S
M96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*
M("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ
M;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S
M('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R
M.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@
M("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q
M=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I
M<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E
M<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER
M92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q
M=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER
M92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*
M("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@
M<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M=#L*("`@(')E<75I<F4@871T<FEB=71E<SL*("`@(&5V86P@>R!R97%U:7)E
M($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@
M>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I<F4@
M07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE($,@
M=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I
M<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@
M87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@
M(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@
M("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*
M("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64[
M"B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E
M=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H
M)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@
M)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U
M:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<[
M"@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["B`@("`@("`@;6MD:7(@
M)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@
M("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@
M("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F
M:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@
M("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@
M("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@
M("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R
M;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@
M("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T
M.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N
M86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X
M(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S
M92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C
M<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE
M;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F
M:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@
M("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA
M;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G
M/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@
M("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E
M<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E
M=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@
M("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P
M.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE
M+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@
M,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I
M('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@
M("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@
M("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD
M("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1
M)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@
M;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@
M("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA
M;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N
M86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@
M(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@
M*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@
M("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R
M;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W
M9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N
M.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$
M14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@
M(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%2
M7R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N
M(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I
M9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?
M0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R
M7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM0
M05)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI
M+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*
M("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB
M.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@
M?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C
M:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC
M(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA
M9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N
M<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U
M8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA
M;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?
M7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)2
M3U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$Q"@I?7T5.1%]?"@``
M`````````````````,!#`1L#.]0````9````2&S___````!8;?__&`$``)AM
M__\P`0``B(/__V`!``!HA/__B`$``+B$__^H`0``V(3__\`!```HA?__V`$`
M`$B%___P`0``&(;__P@"``!HA___*`(``+B'__](`@``B(C__V@"``"8B/__
M@`(``*B*__^X`@``R(O___`"``"(C?__"`,``+B-__\@`P``J([__T`#```8
MC___6`,```B1__]X`P``N)+__[`#``#HG/__Z`,``$B@__\8!```:*#__S`$
M````````%``````````!>E(``7@0`0,,!PB0`0``)````!P```#0'T``G```
M``!!#A"&`D,-!D*-`TN#!8P$`````````!0```!$````X"!``#0`````````
M`````"P```!<````("%``/`5````0@X01@X80@X@00XHA@6,!(T#C@)$#C!'
M#K@$@P8``"0```",````$#=``-D`````2H\"C`5>#D".`XT$A@:#!P``````
M```<````M````/`W0`!/`````$$.$$$.&(,#A@)'#C```!0```#4````0#A`
M`!4`````1`X@`````!0```#L````8#A``$T`````1`X0`````!0````$`0``
ML#A``!X`````1`X0`````!0````<`0``T#A``,(`````2`X0@P(``!P````T
M`0``H#E``$(!````2H,&C`19#K`!C@*-`X8%'````%0!``#P.D``3P````!!
M#A"#`D<.D`$````````<````=`$``$`[0`#)`````%8.P!",`H8#@P0`````
M`!0```"4`0``$#Q```4``````````````#0```"L`0``(#Q```4"````0@X0
M1`X8C@./`D4.($(.*$$.,(8&C`6-!$0..$0.4(,'````````-````.0!```P
M/D``%P$```!"#A!"#AB.`X\"10X@0@XHC`6-!$<.,$$..$0.@`&#!X8&````
M```4````'`(``%`_0`"^`0```$0.0``````4````-`(``!!!0``B`````$0.
M$``````<````3`(``$!!0`#B`````$$.$$$.&(,#A@)'#B```!0```!L`@``
M,$)``&T`````3@X@A@*#`QP```"$`@``H$)``/`!````00X01`XP@P(`````
M````-````*0"``"01$``K`$```!"#A!"#AA"#B!"#BB,!8T$C@./`DD.,$$.
M.(,'A@9*#N`)```````T````W`(``$!&0``L"@```$(.$(\"2@X80@X@0@XH
M00XP00XX1PZ@A`*#!X8&C`6-!(X#`````"P````4`P``<%!``%(#````0@X0
M1PX80@X@00XH00XP1P[`"(,&A@6,!(T#C@(``!0```!$`P``T%-``!0`````
M`````````!0```!<`P``\%-``"<`````1`X0````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````__________\``````````/__________````````````
M``````````$``````````0`````````!``````````T"`````````0``````
M```7`@````````$`````````)0(````````!`````````#("`````````0``
M``````!6`@````````\`````````A@,````````,`````````,`;0```````
M#0````````!45$````````0`````````,`)````````%`````````.@.0```
M````!@````````!8!4````````H`````````J@0````````+`````````!@`
M````````%0````````````````````,`````````&,)@```````"````````
M`-`%````````%``````````'`````````!<`````````\!5````````'````
M`````*`40```````"`````````!0`0````````D`````````&`````````#^
M__]O`````&`40```````____;P`````"`````````/#__V\`````DA-`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````HP&````````````````````````````#J&T```````/H;0```
M````"AQ````````:'$```````"H<0```````.AQ```````!*'$```````%H<
M0```````:AQ```````!Z'$```````(H<0```````FAQ```````"J'$``````
M`+H<0```````RAQ```````#:'$```````.H<0```````^AQ````````*'4``
M`````!H=0```````*AU````````Z'4```````$H=0```````6AU```````!J
M'4```````'H=0```````BAU```````":'4```````*H=0```````NAU`````
M``#*'4```````-H=0```````ZAU```````#Z'4````````H>0```````&AY`
M```````J'D```````#H>0```````2AY```````!:'D```````&H>0```````
M>AY```````"*'D```````)H>0```````JAY```````"Z'D```````,H>0```
M````VAY```````#J'D```````/H>0```````"A]````````:'T```````"H?
M0```````.A]```````!*'T```````%H?0```````:A]```````!Z'T``````
M`(H?0```````FA]```````"J'T```````+H?0```````!59`````````````
M`````!C`8```````R%=```````#_____`"1&<F5E0E-$.B!R96QE87-E+SDN
M,"XP+VQI8B]C<W4O86UD-C0O8W)T,2YC(#(Q-C,S."`R,#$P+3$R+3`Y(#(Q
M.C,Q.C(Q6B!D:6T@)``D1G)E94)31#H@<F5L96%S92\Y+C`N,"]L:6(O8W-U
M+V-O;6UO;B]C<G1B<F%N9"YC(#(Q-S,W-2`R,#$Q+3`Q+3$S(#(P.C0T.C,Q
M6B!D:6T@)`!'0T,Z("A'3E4I(#0N,BXQ(#(P,#<P.#,Q('!A=&-H960@6T9R
M965"4T1=```D1G)E94)31#H@<F5L96%S92\Y+C`N,"]L:6(O8W-U+V%M9#8T
M+V-R=&DN4R`R,3<Q,#4@,C`Q,2TP,2TP-R`Q-CHP-SHU,5H@:VEB("0``$=#
M0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``$=#
M0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``$=#
M0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``"1&
M<F5E0E-$.B!R96QE87-E+SDN,"XP+VQI8B]C<W4O86UD-C0O8W)T;BY3(#(Q
M-S$P-2`R,#$Q+3`Q+3`W(#$V.C`W.C4Q6B!K:6(@)```+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F
M<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O="YP;'0`+F1A
M=&$`+F)S<P`N8V]M;65N=```````````````````````````````````````
M````````````````````````````````````````````````````"P````$`
M```"```````````"0`````````(````````5`````````````````````0``
M`````````````````!,````'`````@`````````8`D```````!@"````````
M&`````````````````````0````````````````````A````!0````(`````
M````,`)````````P`@```````"0#````````!``````````(``````````0`
M````````)P````L````"`````````%@%0```````6`4```````"0"0``````
M``4````!````"``````````8`````````"\````#`````@````````#H#D``
M`````.@.````````J@0```````````````````$````````````````````W
M````____;P(`````````DA-```````"2$P```````,P`````````!```````
M```"``````````(`````````1````/[__V\"`````````&`40```````8!0`
M``````!```````````4````"````"````````````````````%,````$````
M`@````````"@%$```````*`4````````4`$````````$``````````@`````
M````&`````````!=````!`````(`````````\!5```````#P%0```````-`%
M````````!`````L````(`````````!@`````````9P````$````&````````
M`,`;0```````P!L````````3````````````````````!```````````````
M`````&(````!````!@````````#4&T```````-0;````````\`,`````````
M``````````0`````````$`````````!M`````0````8`````````T!]`````
M``#0'P```````(0T```````````````````0````````````````````<P``
M``$````&`````````%140```````5%0````````.````````````````````
M!````````````````````'D````!`````@````````!H5$```````&A4````
M````(%\```````````````````@```````````````````"!`````0````(`
M````````B+-```````"(LP```````-0````````````````````$````````
M````````````CP````$````"`````````&"T0```````8+0```````!T`P``
M````````````````"````````````````````)D````!`````P``````````
MP&````````#`````````$`````````````````````@`````````````````
M``"@`````0````,`````````$,!@```````0P````````!``````````````
M```````(````````````````````IP````$````#`````````"#`8```````
M(,`````````(````````````````````"````````````````````*P````&
M`````P`````````HP&```````"C`````````\`$````````%``````````@`
M````````$`````````"U`````0````,`````````&,)@```````8P@``````
M``@"```````````````````(``````````@`````````O@````$````#````
M`````"#$8```````(,0````````D````````````````````"```````````
M`````````,0````(`````P````````!@Q&```````$3$````````2`4`````
M`````````````"````````````````````#)`````0``````````````````
M``````!$Q````````/<!```````````````````!````````````````````
M`0````,`````````````````````````.\8```````#2````````````````
3`````0``````````````````````
